@@ -53,6 +53,7 @@ class Block:
         *,
         render: bool = True,
         elem_id: str | None = None,
+        elem_classes: List[str] | str | None = None,
         visible: bool = True,
         root_url: str | None = None,  # URL that is prepended to all file paths
         _skip_init_processing: bool = False,  # Used for loading from Spaces
@@ -62,11 +63,15 @@ class Block:
         Context.id += 1
         self.visible = visible
         self.elem_id = elem_id
+        self.elem_classes = (
+            [elem_classes] if isinstance(elem_classes, str) else elem_classes
+        )
         self.root_url = root_url
         self.share_token = secrets.token_urlsafe(32)
         self._skip_init_processing = _skip_init_processing
         self._style = {}
         self.parent: BlockContext | None = None
+        self.root = ""
 
         if render:
             self.render()
@@ -263,6 +268,7 @@ class Block:
         return {
             "visible": self.visible,
             "elem_id": self.elem_id,
+            "elem_classes": self.elem_classes,
             "style": self._style,
             "root_url": self.root_url,
         }
@@ -394,6 +400,9 @@ def postprocess_update_dict(block: Block, update_dict: Dict, postprocess: bool =
         update_dict = block.get_specific_update(update_dict)
     if update_dict.get("value") is components._Keywords.NO_VALUE:
         update_dict.pop("value")
+    interactive = update_dict.pop("interactive", None)
+    if interactive is not None:
+        update_dict["mode"] = "dynamic" if interactive else "static"
     prediction_value = delete_none(update_dict, skip_value=True)
     if "value" in prediction_value and postprocess:
         assert isinstance(
@@ -491,7 +500,8 @@ class Blocks(BlockContext):
             warnings.warn("Theme should be a class loaded from gradio.themes")
             theme = DefaultTheme()
         self.theme = theme
-        self.theme_css = self.theme._get_theme_css()
+        self.theme_css = theme._get_theme_css()
+        self.stylesheets = theme._stylesheets
         self.encrypt = False
         self.share = False
         self.enable_queue = None
@@ -1097,6 +1107,8 @@ class Blocks(BlockContext):
             "show_error": getattr(self, "show_error", False),
             "show_api": self.show_api,
             "is_colab": utils.colab_check(),
+            "stylesheets": self.stylesheets,
+            "root": self.root,
         }
 
         def getLayout(block):
