@@ -2,6 +2,7 @@ XRAY_CONFIG = {
     "version": "3.4b3\n",
     "mode": "blocks",
     "dev_mode": True,
+    "analytics_enabled": False,
     "components": [
         {
             "id": 27,
@@ -68,6 +69,7 @@ XRAY_CONFIG = {
             "props": {
                 "value": "Run",
                 "variant": "secondary",
+                "interactive": True,
                 "name": "button",
                 "visible": True,
                 "style": {},
@@ -115,6 +117,7 @@ XRAY_CONFIG = {
                 "value": "Run",
                 "variant": "secondary",
                 "name": "button",
+                "interactive": True,
                 "visible": True,
                 "style": {},
             },
@@ -126,6 +129,7 @@ XRAY_CONFIG = {
                 "lines": 1,
                 "max_lines": 20,
                 "value": "",
+                "type": "text",
                 "show_label": True,
                 "name": "textbox",
                 "visible": True,
@@ -143,7 +147,6 @@ XRAY_CONFIG = {
             "props": {"type": "form", "visible": True, "style": {}},
         },
     ],
-    "theme": "default",
     "css": None,
     "title": "Gradio",
     "is_space": False,
@@ -193,6 +196,10 @@ XRAY_CONFIG = {
             "max_batch_size": 4,
             "cancels": [],
             "every": None,
+            "collects_event_data": False,
+            "types": {"continuous": False, "generator": False},
+            "trigger_after": None,
+            "trigger_only_on_success": False,
         },
         {
             "targets": [39],
@@ -209,6 +216,10 @@ XRAY_CONFIG = {
             "max_batch_size": 4,
             "cancels": [],
             "every": None,
+            "collects_event_data": False,
+            "types": {"continuous": False, "generator": False},
+            "trigger_after": None,
+            "trigger_only_on_success": False,
         },
         {
             "targets": [],
@@ -225,6 +236,10 @@ XRAY_CONFIG = {
             "max_batch_size": 4,
             "cancels": [],
             "every": None,
+            "collects_event_data": False,
+            "types": {"continuous": False, "generator": False},
+            "trigger_after": None,
+            "trigger_only_on_success": False,
         },
     ],
 }
@@ -233,6 +248,7 @@ XRAY_CONFIG = {
 XRAY_CONFIG_DIFF_IDS = {
     "version": "3.4b3\n",
     "mode": "blocks",
+    "analytics_enabled": False,
     "dev_mode": True,
     "components": [
         {
@@ -300,6 +316,7 @@ XRAY_CONFIG_DIFF_IDS = {
             "props": {
                 "value": "Run",
                 "variant": "secondary",
+                "interactive": True,
                 "name": "button",
                 "visible": True,
                 "style": {},
@@ -346,6 +363,7 @@ XRAY_CONFIG_DIFF_IDS = {
             "props": {
                 "value": "Run",
                 "variant": "secondary",
+                "interactive": True,
                 "name": "button",
                 "visible": True,
                 "style": {},
@@ -358,6 +376,7 @@ XRAY_CONFIG_DIFF_IDS = {
                 "lines": 1,
                 "max_lines": 20,
                 "value": "",
+                "type": "text",
                 "show_label": True,
                 "name": "textbox",
                 "visible": True,
@@ -375,7 +394,6 @@ XRAY_CONFIG_DIFF_IDS = {
             "props": {"type": "form", "visible": True, "style": {}},
         },
     ],
-    "theme": "default",
     "css": None,
     "title": "Gradio",
     "is_space": False,
@@ -425,6 +443,10 @@ XRAY_CONFIG_DIFF_IDS = {
             "max_batch_size": 4,
             "cancels": [],
             "every": None,
+            "collects_event_data": False,
+            "types": {"continuous": False, "generator": False},
+            "trigger_after": None,
+            "trigger_only_on_success": False,
         },
         {
             "targets": [933],
@@ -441,6 +463,10 @@ XRAY_CONFIG_DIFF_IDS = {
             "max_batch_size": 4,
             "cancels": [],
             "every": None,
+            "collects_event_data": False,
+            "types": {"continuous": False, "generator": False},
+            "trigger_after": None,
+            "trigger_only_on_success": False,
         },
         {
             "targets": [],
@@ -457,6 +483,10 @@ XRAY_CONFIG_DIFF_IDS = {
             "max_batch_size": 4,
             "cancels": [],
             "every": None,
+            "collects_event_data": False,
+            "types": {"continuous": False, "generator": False},
+            "trigger_after": None,
+            "trigger_only_on_success": False,
         },
     ],
 }
@@ -465,6 +495,7 @@ XRAY_CONFIG_DIFF_IDS = {
 XRAY_CONFIG_WITH_MISTAKE = {
     "mode": "blocks",
     "dev_mode": True,
+    "analytics_enabled": False,
     "components": [
         {
             "id": 1,
@@ -536,6 +567,7 @@ XRAY_CONFIG_WITH_MISTAKE = {
             "props": {
                 "value": "Run",
                 "name": "button",
+                "interactive": True,
                 "css": {"background-color": "red", "--hover-color": "orange"},
                 "variant": "secondary",
             },
@@ -581,6 +613,7 @@ XRAY_CONFIG_WITH_MISTAKE = {
             "type": "button",
             "props": {
                 "value": "Run",
+                "interactive": True,
                 "name": "button",
                 "style": {},
                 "variant": "secondary",
@@ -593,11 +626,11 @@ XRAY_CONFIG_WITH_MISTAKE = {
                 "lines": 1,
                 "value": "",
                 "name": "textbox",
+                "type": "text",
                 "style": {},
             },
         },
     ],
-    "theme": "default",
     "layout": {
         "id": 0,
         "children": [
@@ -635,6 +668,8 @@ XRAY_CONFIG_WITH_MISTAKE = {
             "scroll_to_output": False,
             "show_progress": True,
             "cancels": [],
+            "trigger_after": None,
+            "trigger_only_on_success": False,
         },
         {
             "targets": [13],
@@ -645,6 +680,8 @@ XRAY_CONFIG_WITH_MISTAKE = {
             "scroll_to_output": False,
             "show_progress": True,
             "cancels": [],
+            "trigger_after": None,
+            "trigger_only_on_success": False,
         },
     ],
 }
